@@ -56,12 +56,12 @@ def get_status(request):
         context['clientstatus']=Util.check_client(save_dir,key)
         context['result']=Util.check_client_all(save_dir,keys)
         print('context[\'result\']',context['result'])
-        # if int(context['result'])==3:
-        if os.path.exists(os.path.join(save_dir,'%s_model'%(key))):
-            os.rename(os.path.join(save_dir,'%s_model'%(key)),os.path.join(save_dir,'%s_modelb'%(key)))
-            context['modelurl']=os.path.join(save_dir,'%s_modelb'%(key)).replace(BASE_DIR,'')
-        else:
-            Util.check_fed_model(save_dir,keys,0,0,10)
+        if int(context['clientstatus'])==0:
+            if os.path.exists(os.path.join(save_dir,'%s_model'%(key))):
+                os.rename(os.path.join(save_dir,'%s_model'%(key)),os.path.join(save_dir,'%s_modelb'%(key)))
+                context['modelurl']=os.path.join(save_dir,'%s_modelb'%(key)).replace(BASE_DIR,'')
+            else:
+                Util.check_fed_model(save_dir,keys,0,0,10)
         print(context)
         # Util.addtasklog(ut.save_dir,'get_status',taskid,clientid,'result',context['result'],context['modelurl'],context['clienttrain'])
     return HttpResponse(json.dumps(context),content_type="application/json") 
